modelling Package
=================

:mod:`modelling` Package
------------------------

.. automodule:: masai.modelling
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`models` Module
--------------------

.. automodule:: masai.modelling.models
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`optimize` Module
----------------------

.. automodule:: masai.modelling.optimize
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`parameters` Module
------------------------

.. automodule:: masai.modelling.parameters
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sequence` Module
----------------------

.. automodule:: masai.modelling.sequence
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    masai.modelling.pulsar

